Nodal 2 SVG
===========

This package creates SVG image from a Nodal ``.nod`` document. Allowing
for Nodal matrices to be viewed & presented independently of the Nodal.app
application.

Basic Usage
-----------

.. code-block:: console

    $ nod2svg generative_music.nod generative_export.svg

